@@ -1,5 +1,5 @@
 from .formatters import SatCFDI
 from .process import invoices_print, payments_print,  invoices_confirmation_print
 from .process import invoices_export, payments_export, retentions_export, payments_retentions_export
-from .process import filter_invoices_by, filter_payments_by, filter_retenciones_by, complement_invoices_data, InvoiceType
+from .process import filter_invoices_iter, filter_payments_iter, filter_retenciones_iter, complement_invoices_data
 from .email import EmailManager
