@@ -3,15 +3,14 @@ from collections.abc import Sequence
 from dataclasses import dataclass
 from datetime import datetime
 from decimal import Decimal
-from typing import Iterator
 
+from .. import Signer
 from . import pago20
-from ..compute import make_impuestos, rounder, make_impuestos_dr, make_impuesto, \
+from ..compute import make_impuestos, rounder, make_impuesto, \
     make_impuestos_dr_parcial
-from ... import CFDI, XElement, ScalarMap
-from ...create import Issuer
-from ...utils import iterate
+from ... import CFDI, ScalarMap
 from ...transform import get_timezone
+from ...utils import iterate
 
 _impuestos = {
     "ISR": "001",
@@ -329,6 +328,31 @@ class Receptor(ScalarMap):
         })
 
 
+class Emisor(ScalarMap):
+    """
+    Nodo requerido para expresar la información del contribuyente emisor del comprobante.
+
+    :param rfc: Atributo requerido para registrar la Clave del Registro Federal de Contribuyentes correspondiente al contribuyente emisor del comprobante.
+    :param nombre: Atributo requerido para registrar el nombre, denominación o razón social del contribuyente inscrito en el RFC, del emisor del comprobante.
+    :param regimen_fiscal: Atributo requerido para incorporar la clave del régimen del contribuyente emisor al que aplicará el efecto fiscal de este comprobante.
+    :param fac_atr_adquirente: Atributo condicional para expresar el número de operación proporcionado por el SAT cuando se trate de un comprobante a través de un PCECFDI o un PCGCFDISP.
+    """
+
+    def __init__(
+            self,
+            rfc: str,
+            nombre: str,
+            regimen_fiscal: str,
+            fac_atr_adquirente: str = None,
+    ):
+        super().__init__({
+            'Rfc': rfc,
+            'Nombre': nombre,
+            'RegimenFiscal': regimen_fiscal,
+            'FacAtrAdquirente': fac_atr_adquirente,
+        })
+        
+
 @dataclass
 class PagoComprobante:
     comprobante: CFDI
@@ -417,7 +441,7 @@ class Comprobante(CFDI):
 
     def __init__(
             self,
-            emisor: Issuer,
+            emisor: Emisor | dict,
             lugar_expedicion: str,
             receptor: Receptor | dict,
             conceptos: Concepto | Sequence[Concepto | dict],
@@ -437,28 +461,13 @@ class Comprobante(CFDI):
             addenda: CFDI | Sequence[CFDI] = None,
             fecha: datetime = None,
     ):
-        conceptos = _make_conceptos(conceptos, rnd_fn=rounder(moneda))
-        sub_total = sum(c['Importe'] for c in conceptos)
-        descuento = sum(c.get('Descuento') or 0 for c in conceptos)
-        impuestos = make_impuestos(conceptos)
-
-        total = sub_total - descuento
-        if impuestos:
-            total += impuestos.get('TotalImpuestosTrasladados', 0)
-            total -= impuestos.get('TotalImpuestosRetenidos', 0)
-
-        descuento = descuento or None
-        fecha = fecha or datetime.now(tz=get_timezone(lugar_expedicion)).replace(tzinfo=None)
-
         super().__init__({
-            'Version': self.version,
+            'Version': None,
             'Fecha': fecha,
-            'NoCertificado': emisor.certificate_number,
-            'Certificado': emisor.signer.certificate_base64() if emisor.signer else '',
             'Sello': '',
-            'SubTotal': sub_total,
+            'SubTotal': None,
             'Moneda': moneda,
-            'Total': total,
+            'Total': None,
             'TipoDeComprobante': tipo_de_comprobante,
             'Exportacion': exportacion,
             'LugarExpedicion': lugar_expedicion,
@@ -466,32 +475,55 @@ class Comprobante(CFDI):
             'Folio': folio,
             'FormaPago': forma_pago,
             'CondicionesDePago': condiciones_de_pago,
-            'Descuento': descuento,
+            'Descuento': None,
             'TipoCambio': tipo_cambio,
             'MetodoPago': metodo_pago,
             'Confirmacion': confirmacion,
             'InformacionGlobal': informacion_global,
             'CfdiRelacionados': cfdi_relacionados,
-            'Emisor': {
-                "Rfc": emisor.rfc,
-                "Nombre": emisor.legal_name,
-                "RegimenFiscal": emisor.tax_system
-            },
+            'Emisor': emisor,
             'Receptor': receptor,
             'Conceptos': conceptos,
-            'Impuestos': impuestos,
+            'Impuestos': None,
             'Complemento': complemento,
             'Addenda': addenda,
+            'NoCertificado': '',
+            'Certificado': '',
         })
-        if emisor.signer:
-            self['Sello'] = emisor.signer.sign_sha256(
-                self.cadena_original().encode()
-            )
+        self.compute()
+
+    def compute(self):
+        self['Version'] = self.version
+        self['Fecha'] = self.get('Fecha') or datetime.now(tz=get_timezone(self['LugarExpedicion'])).replace(tzinfo=None)
+        self['Moneda'] = self.get('Moneda') or 'MXN'
+        self['Sello'] = ''
+        self['TipoDeComprobante'] = self.get('TipoDeComprobante') or 'I'
+        self['Exportacion'] = self.get('Exportacion') or '01'
+
+        self["Conceptos"] = conceptos = _make_conceptos(self["Conceptos"], rnd_fn=rounder(self["Moneda"]))
+        self["SubTotal"] = sub_total = sum(c['Importe'] for c in conceptos)
+        descuento = sum(c.get('Descuento') or 0 for c in conceptos)
+        self['Impuestos'] = impuestos = make_impuestos(conceptos)
+
+        total = sub_total - descuento
+        if impuestos:
+            total += impuestos.get('TotalImpuestosTrasladados', 0)
+            total -= impuestos.get('TotalImpuestosRetenidos', 0)
+
+        self['Total'] = total
+        self['Descuento'] = descuento or None
+
+    def sign(self, signer: Signer):
+        self['NoCertificado'] = signer.certificate_number
+        self['Certificado'] = signer.certificate_base64()
+        self['Sello'] = signer.sign_sha256(
+            self.cadena_original().encode()
+        )
 
     @classmethod
     def pago(
             cls,
-            emisor: Issuer,
+            emisor: Emisor | dict,
             lugar_expedicion: str,
             receptor: Receptor | dict,
             complemento_pago: CFDI,
@@ -559,11 +591,12 @@ class Comprobante(CFDI):
     @classmethod
     def pago_comprobantes(
             cls,
-            emisor: Issuer,
-            lugar_expedicion: str,
             comprobantes: CFDI | PagoComprobante | Sequence[CFDI | PagoComprobante],
             fecha_pago: datetime,
             forma_pago: str,
+            emisor: Emisor | dict = None,
+            lugar_expedicion: str = None,
+            receptor: Receptor | dict = None,
             tipo_cambio: Decimal | int = None,
             cfdi_relacionados: CfdiRelacionados | Sequence[CfdiRelacionados | dict] = None,
             confirmacion: str = None,
@@ -577,6 +610,7 @@ class Comprobante(CFDI):
 
         :param emisor: Nodo requerido para expresar la información del contribuyente emisor del comprobante.
         :param lugar_expedicion: Atributo requerido para incorporar el código postal del lugar de expedición del comprobante (domicilio de la matriz o de la sucursal).
+        :param receptor: Nodo requerido para precisar la información del contribuyente receptor del comprobante.
         :param comprobantes: CFDI(s) de Comprobante de Ingreso para generar el pago por su monto total o parcial usando PagoComprobante
         :param fecha_pago: Atributo requerido para expresar la fecha y hora en la que el beneficiario recibe el pago. Se expresa en la forma aaaa-mm-ddThh:mm:ss, de acuerdo con la especificación ISO 8601.En caso de no contar con la hora se debe registrar 12:00:00.
         :param serie: Atributo opcional para precisar la serie para control interno del contribuyente. Este atributo acepta una cadena de caracteres.
@@ -592,13 +626,17 @@ class Comprobante(CFDI):
         comprobantes = [c if isinstance(c, PagoComprobante) else PagoComprobante(comprobante=c) for c in iterate(comprobantes)]
         first_cfdi = comprobantes[0].comprobante
         moneda = first_cfdi['Moneda']
-        receptor = first_cfdi['Receptor'].copy()
+
+        emisor = emisor or first_cfdi['Emisor'].copy()
+        lugar_expedicion = lugar_expedicion or first_cfdi['LugarExpedicion']
+        receptor = receptor or first_cfdi['Receptor'].copy()
+
         tipo_cambio = cls._pago_tipo_cambio(moneda, tipo_cambio)
 
         if not all(
                 c.comprobante["Moneda"] == moneda
-                and c.comprobante["Emisor"]["Rfc"] == emisor.rfc
-                and c.comprobante["Emisor"]["RegimenFiscal"] == emisor.tax_system
+                and c.comprobante["Emisor"]["Rfc"] == emisor["Rfc"]
+                and c.comprobante["Emisor"]["RegimenFiscal"] == emisor["RegimenFiscal"]
                 and c.comprobante["Receptor"]["Rfc"] == receptor["Rfc"]
                 and c.comprobante["Receptor"].get("RegimenFiscalReceptor") == receptor.get("RegimenFiscalReceptor")
                 for c in comprobantes
@@ -649,7 +687,7 @@ class Comprobante(CFDI):
     @classmethod
     def nomina(
             cls,
-            emisor: Issuer,
+            emisor: Emisor | dict,
             lugar_expedicion: str,
             receptor: Receptor | dict,
             complemento_nomina: CFDI,
