@@ -1,10 +1,19 @@
+"""mpc http://www.uif.shcp.gob.mx/recepcion/mpc"""
 from decimal import Decimal
 from datetime import datetime, date, time
 from collections.abc import Sequence
-from ...cfdi import CFDI, XElement
+from ... import CFDI, XElement, ScalarMap
 
 
-class DatosLiquidacionType(XElement):
+class DatosLiquidacionType(ScalarMap):
+    """
+    
+    :param fecha_disposicion:
+    :param instrumento_monetario:
+    :param moneda:
+    :param monto_operacion:
+    """
+    
     def __init__(
             self,
             fecha_disposicion: date,
@@ -12,14 +21,6 @@ class DatosLiquidacionType(XElement):
             moneda: str,
             monto_operacion: str,
     ): 
-        """
-        
-        :param fecha_disposicion:
-        :param instrumento_monetario:
-        :param moneda:
-        :param monto_operacion:
-        """
-        
         super().__init__({
             'FechaDisposicion': fecha_disposicion,
             'InstrumentoMonetario': instrumento_monetario,
@@ -28,20 +29,20 @@ class DatosLiquidacionType(XElement):
         })
         
 
-class FideicomisoGaranteType(XElement):
+class FideicomisoGaranteType(ScalarMap):
+    """
+    
+    :param denominacion_razon:
+    :param rfc:
+    :param identificador_fideicomiso:
+    """
+    
     def __init__(
             self,
             denominacion_razon: str,
             rfc: str = None,
             identificador_fideicomiso: str = None,
     ): 
-        """
-        
-        :param denominacion_razon:
-        :param rfc:
-        :param identificador_fideicomiso:
-        """
-        
         super().__init__({
             'DenominacionRazon': denominacion_razon,
             'Rfc': rfc,
@@ -49,20 +50,20 @@ class FideicomisoGaranteType(XElement):
         })
         
 
-class PersonaMoralGaranteType(XElement):
+class PersonaMoralGaranteType(ScalarMap):
+    """
+    
+    :param denominacion_razon:
+    :param fecha_constitucion:
+    :param rfc:
+    """
+    
     def __init__(
             self,
             denominacion_razon: str,
             fecha_constitucion: date = None,
             rfc: str = None,
     ): 
-        """
-        
-        :param denominacion_razon:
-        :param fecha_constitucion:
-        :param rfc:
-        """
-        
         super().__init__({
             'DenominacionRazon': denominacion_razon,
             'FechaConstitucion': fecha_constitucion,
@@ -70,7 +71,17 @@ class PersonaMoralGaranteType(XElement):
         })
         
 
-class PersonaFisicaGaranteType(XElement):
+class PersonaFisicaGaranteType(ScalarMap):
+    """
+    
+    :param nombre:
+    :param apellido_paterno:
+    :param apellido_materno:
+    :param fecha_nacimiento:
+    :param rfc:
+    :param curp:
+    """
+    
     def __init__(
             self,
             nombre: str,
@@ -80,16 +91,6 @@ class PersonaFisicaGaranteType(XElement):
             rfc: str = None,
             curp: str = None,
     ): 
-        """
-        
-        :param nombre:
-        :param apellido_paterno:
-        :param apellido_materno:
-        :param fecha_nacimiento:
-        :param rfc:
-        :param curp:
-        """
-        
         super().__init__({
             'Nombre': nombre,
             'ApellidoPaterno': apellido_paterno,
@@ -100,20 +101,20 @@ class PersonaFisicaGaranteType(XElement):
         })
         
 
-class TipoGaranteType(XElement):
+class TipoGaranteType(ScalarMap):
+    """
+    
+    :param persona_fisica:
+    :param persona_moral:
+    :param fideicomiso:
+    """
+    
     def __init__(
             self,
             persona_fisica: PersonaFisicaGaranteType | dict = None,
             persona_moral: PersonaMoralGaranteType | dict = None,
             fideicomiso: FideicomisoGaranteType | dict = None,
     ): 
-        """
-        
-        :param persona_fisica:
-        :param persona_moral:
-        :param fideicomiso:
-        """
-        
         super().__init__({
             'PersonaFisica': persona_fisica,
             'PersonaMoral': persona_moral,
@@ -121,22 +122,30 @@ class TipoGaranteType(XElement):
         })
         
 
-class DatosOtroType(XElement):
+class DatosOtroType(ScalarMap):
+    """
+    
+    :param descripcion_garantia:
+    """
+    
     def __init__(
             self,
             descripcion_garantia: str,
     ): 
-        """
-        
-        :param descripcion_garantia:
-        """
-        
         super().__init__({
             'DescripcionGarantia': descripcion_garantia,
         })
         
 
-class DatosInmuebleType(XElement):
+class DatosInmuebleType(ScalarMap):
+    """
+    
+    :param tipo_inmueble:
+    :param valor_referencia:
+    :param codigo_postal:
+    :param folio_real:
+    """
+    
     def __init__(
             self,
             tipo_inmueble: str,
@@ -144,14 +153,6 @@ class DatosInmuebleType(XElement):
             codigo_postal: str,
             folio_real: str,
     ): 
-        """
-        
-        :param tipo_inmueble:
-        :param valor_referencia:
-        :param codigo_postal:
-        :param folio_real:
-        """
-        
         super().__init__({
             'TipoInmueble': tipo_inmueble,
             'ValorReferencia': valor_referencia,
@@ -160,38 +161,38 @@ class DatosInmuebleType(XElement):
         })
         
 
-class DatosBienMutuoType(XElement):
+class DatosBienMutuoType(ScalarMap):
+    """
+    
+    :param datos_inmueble:
+    :param datos_otro:
+    """
+    
     def __init__(
             self,
             datos_inmueble: DatosInmuebleType | dict = None,
             datos_otro: DatosOtroType | dict = None,
     ): 
-        """
-        
-        :param datos_inmueble:
-        :param datos_otro:
-        """
-        
         super().__init__({
             'DatosInmueble': datos_inmueble,
             'DatosOtro': datos_otro,
         })
         
 
-class DatosGarantiaType(XElement):
+class DatosGarantiaType(ScalarMap):
+    """
+    
+    :param tipo_garantia:
+    :param datos_bien_mutuo:
+    :param tipo_persona:
+    """
+    
     def __init__(
             self,
             tipo_garantia: str,
             datos_bien_mutuo: DatosBienMutuoType | dict = None,
             tipo_persona: TipoGaranteType | dict = None,
     ): 
-        """
-        
-        :param tipo_garantia:
-        :param datos_bien_mutuo:
-        :param tipo_persona:
-        """
-        
         super().__init__({
             'TipoGarantia': tipo_garantia,
             'DatosBienMutuo': datos_bien_mutuo,
@@ -199,7 +200,16 @@ class DatosGarantiaType(XElement):
         })
         
 
-class DatosOperacionType(XElement):
+class DatosOperacionType(ScalarMap):
+    """
+    
+    :param fecha_operacion:
+    :param codigo_postal:
+    :param tipo_operacion:
+    :param datos_liquidacion:
+    :param datos_garantia:
+    """
+    
     def __init__(
             self,
             fecha_operacion: date,
@@ -208,15 +218,6 @@ class DatosOperacionType(XElement):
             datos_liquidacion: DatosLiquidacionType | dict | Sequence[DatosLiquidacionType | dict],
             datos_garantia: DatosGarantiaType | dict | Sequence[DatosGarantiaType | dict] = None,
     ): 
-        """
-        
-        :param fecha_operacion:
-        :param codigo_postal:
-        :param tipo_operacion:
-        :param datos_liquidacion:
-        :param datos_garantia:
-        """
-        
         super().__init__({
             'FechaOperacion': fecha_operacion,
             'CodigoPostal': codigo_postal,
@@ -226,35 +227,35 @@ class DatosOperacionType(XElement):
         })
         
 
-class DetalleOperacionesType(XElement):
+class DetalleOperacionesType(ScalarMap):
+    """
+    
+    :param datos_operacion:
+    """
+    
     def __init__(
             self,
             datos_operacion: DatosOperacionType | dict | Sequence[DatosOperacionType | dict],
     ): 
-        """
-        
-        :param datos_operacion:
-        """
-        
         super().__init__({
             'DatosOperacion': datos_operacion,
         })
         
 
-class FideicomisoSimpleType(XElement):
+class FideicomisoSimpleType(ScalarMap):
+    """
+    
+    :param denominacion_razon:
+    :param rfc:
+    :param identificador_fideicomiso:
+    """
+    
     def __init__(
             self,
             denominacion_razon: str,
             rfc: str = None,
             identificador_fideicomiso: str = None,
     ): 
-        """
-        
-        :param denominacion_razon:
-        :param rfc:
-        :param identificador_fideicomiso:
-        """
-        
         super().__init__({
             'DenominacionRazon': denominacion_razon,
             'Rfc': rfc,
@@ -262,7 +263,15 @@ class FideicomisoSimpleType(XElement):
         })
         
 
-class PersonaMoralSimpleType(XElement):
+class PersonaMoralSimpleType(ScalarMap):
+    """
+    
+    :param denominacion_razon:
+    :param fecha_constitucion:
+    :param rfc:
+    :param pais_nacionalidad:
+    """
+    
     def __init__(
             self,
             denominacion_razon: str,
@@ -270,14 +279,6 @@ class PersonaMoralSimpleType(XElement):
             rfc: str = None,
             pais_nacionalidad: str = None,
     ): 
-        """
-        
-        :param denominacion_razon:
-        :param fecha_constitucion:
-        :param rfc:
-        :param pais_nacionalidad:
-        """
-        
         super().__init__({
             'DenominacionRazon': denominacion_razon,
             'FechaConstitucion': fecha_constitucion,
@@ -286,7 +287,18 @@ class PersonaMoralSimpleType(XElement):
         })
         
 
-class PersonaFisicaSimpleType(XElement):
+class PersonaFisicaSimpleType(ScalarMap):
+    """
+    
+    :param nombre:
+    :param apellido_paterno:
+    :param apellido_materno:
+    :param fecha_nacimiento:
+    :param rfc:
+    :param curp:
+    :param pais_nacionalidad:
+    """
+    
     def __init__(
             self,
             nombre: str,
@@ -297,17 +309,6 @@ class PersonaFisicaSimpleType(XElement):
             curp: str = None,
             pais_nacionalidad: str = None,
     ): 
-        """
-        
-        :param nombre:
-        :param apellido_paterno:
-        :param apellido_materno:
-        :param fecha_nacimiento:
-        :param rfc:
-        :param curp:
-        :param pais_nacionalidad:
-        """
-        
         super().__init__({
             'Nombre': nombre,
             'ApellidoPaterno': apellido_paterno,
@@ -319,20 +320,20 @@ class PersonaFisicaSimpleType(XElement):
         })
         
 
-class TipoPersonaSimpleType(XElement):
+class TipoPersonaSimpleType(ScalarMap):
+    """
+    
+    :param persona_fisica:
+    :param persona_moral:
+    :param fideicomiso:
+    """
+    
     def __init__(
             self,
             persona_fisica: PersonaFisicaSimpleType | dict = None,
             persona_moral: PersonaMoralSimpleType | dict = None,
             fideicomiso: FideicomisoSimpleType | dict = None,
     ): 
-        """
-        
-        :param persona_fisica:
-        :param persona_moral:
-        :param fideicomiso:
-        """
-        
         super().__init__({
             'PersonaFisica': persona_fisica,
             'PersonaMoral': persona_moral,
@@ -340,35 +341,35 @@ class TipoPersonaSimpleType(XElement):
         })
         
 
-class DuenoBeneficiarioType(XElement):
+class DuenoBeneficiarioType(ScalarMap):
+    """
+    
+    :param tipo_persona:
+    """
+    
     def __init__(
             self,
             tipo_persona: TipoPersonaSimpleType | dict,
     ): 
-        """
-        
-        :param tipo_persona:
-        """
-        
         super().__init__({
             'TipoPersona': tipo_persona,
         })
         
 
-class TelefonoType(XElement):
+class TelefonoType(ScalarMap):
+    """
+    
+    :param clave_pais:
+    :param numero_telefono:
+    :param correo_electronico:
+    """
+    
     def __init__(
             self,
             clave_pais: str = None,
             numero_telefono: str = None,
             correo_electronico: str = None,
     ): 
-        """
-        
-        :param clave_pais:
-        :param numero_telefono:
-        :param correo_electronico:
-        """
-        
         super().__init__({
             'ClavePais': clave_pais,
             'NumeroTelefono': numero_telefono,
@@ -376,7 +377,19 @@ class TelefonoType(XElement):
         })
         
 
-class ExtranjeroType(XElement):
+class ExtranjeroType(ScalarMap):
+    """
+    
+    :param pais:
+    :param estado_provincia:
+    :param ciudad_poblacion:
+    :param colonia:
+    :param calle:
+    :param numero_exterior:
+    :param codigo_postal:
+    :param numero_interior:
+    """
+    
     def __init__(
             self,
             pais: str,
@@ -388,18 +401,6 @@ class ExtranjeroType(XElement):
             codigo_postal: str,
             numero_interior: str = None,
     ): 
-        """
-        
-        :param pais:
-        :param estado_provincia:
-        :param ciudad_poblacion:
-        :param colonia:
-        :param calle:
-        :param numero_exterior:
-        :param codigo_postal:
-        :param numero_interior:
-        """
-        
         super().__init__({
             'Pais': pais,
             'EstadoProvincia': estado_provincia,
@@ -412,7 +413,16 @@ class ExtranjeroType(XElement):
         })
         
 
-class NacionalType(XElement):
+class NacionalType(ScalarMap):
+    """
+    
+    :param colonia:
+    :param calle:
+    :param numero_exterior:
+    :param codigo_postal:
+    :param numero_interior:
+    """
+    
     def __init__(
             self,
             colonia: str,
@@ -421,15 +431,6 @@ class NacionalType(XElement):
             codigo_postal: str,
             numero_interior: str = None,
     ): 
-        """
-        
-        :param colonia:
-        :param calle:
-        :param numero_exterior:
-        :param codigo_postal:
-        :param numero_interior:
-        """
-        
         super().__init__({
             'Colonia': colonia,
             'Calle': calle,
@@ -439,25 +440,35 @@ class NacionalType(XElement):
         })
         
 
-class TipoDomicilioType(XElement):
+class TipoDomicilioType(ScalarMap):
+    """
+    
+    :param nacional:
+    :param extranjero:
+    """
+    
     def __init__(
             self,
             nacional: NacionalType | dict = None,
             extranjero: ExtranjeroType | dict = None,
     ): 
-        """
-        
-        :param nacional:
-        :param extranjero:
-        """
-        
         super().__init__({
             'Nacional': nacional,
             'Extranjero': extranjero,
         })
         
 
-class RepresentanteApoderadoType(XElement):
+class RepresentanteApoderadoType(ScalarMap):
+    """
+    
+    :param nombre:
+    :param apellido_paterno:
+    :param apellido_materno:
+    :param fecha_nacimiento:
+    :param rfc:
+    :param curp:
+    """
+    
     def __init__(
             self,
             nombre: str,
@@ -467,16 +478,6 @@ class RepresentanteApoderadoType(XElement):
             rfc: str = None,
             curp: str = None,
     ): 
-        """
-        
-        :param nombre:
-        :param apellido_paterno:
-        :param apellido_materno:
-        :param fecha_nacimiento:
-        :param rfc:
-        :param curp:
-        """
-        
         super().__init__({
             'Nombre': nombre,
             'ApellidoPaterno': apellido_paterno,
@@ -487,7 +488,15 @@ class RepresentanteApoderadoType(XElement):
         })
         
 
-class FideicomisoType(XElement):
+class FideicomisoType(ScalarMap):
+    """
+    
+    :param denominacion_razon:
+    :param apoderado_delegado:
+    :param rfc:
+    :param identificador_fideicomiso:
+    """
+    
     def __init__(
             self,
             denominacion_razon: str,
@@ -495,14 +504,6 @@ class FideicomisoType(XElement):
             rfc: str = None,
             identificador_fideicomiso: str = None,
     ): 
-        """
-        
-        :param denominacion_razon:
-        :param apoderado_delegado:
-        :param rfc:
-        :param identificador_fideicomiso:
-        """
-        
         super().__init__({
             'DenominacionRazon': denominacion_razon,
             'ApoderadoDelegado': apoderado_delegado,
@@ -511,7 +512,17 @@ class FideicomisoType(XElement):
         })
         
 
-class PersonaMoralType(XElement):
+class PersonaMoralType(ScalarMap):
+    """
+    
+    :param denominacion_razon:
+    :param pais_nacionalidad:
+    :param giro_mercantil:
+    :param representante_apoderado:
+    :param fecha_constitucion:
+    :param rfc:
+    """
+    
     def __init__(
             self,
             denominacion_razon: str,
@@ -521,16 +532,6 @@ class PersonaMoralType(XElement):
             fecha_constitucion: date = None,
             rfc: str = None,
     ): 
-        """
-        
-        :param denominacion_razon:
-        :param pais_nacionalidad:
-        :param giro_mercantil:
-        :param representante_apoderado:
-        :param fecha_constitucion:
-        :param rfc:
-        """
-        
         super().__init__({
             'DenominacionRazon': denominacion_razon,
             'PaisNacionalidad': pais_nacionalidad,
@@ -541,7 +542,19 @@ class PersonaMoralType(XElement):
         })
         
 
-class PersonaFisicaType(XElement):
+class PersonaFisicaType(ScalarMap):
+    """
+    
+    :param nombre:
+    :param apellido_paterno:
+    :param apellido_materno:
+    :param pais_nacionalidad:
+    :param actividad_economica:
+    :param fecha_nacimiento:
+    :param rfc:
+    :param curp:
+    """
+    
     def __init__(
             self,
             nombre: str,
@@ -553,18 +566,6 @@ class PersonaFisicaType(XElement):
             rfc: str = None,
             curp: str = None,
     ): 
-        """
-        
-        :param nombre:
-        :param apellido_paterno:
-        :param apellido_materno:
-        :param pais_nacionalidad:
-        :param actividad_economica:
-        :param fecha_nacimiento:
-        :param rfc:
-        :param curp:
-        """
-        
         super().__init__({
             'Nombre': nombre,
             'ApellidoPaterno': apellido_paterno,
@@ -577,20 +578,20 @@ class PersonaFisicaType(XElement):
         })
         
 
-class TipoPersonaType(XElement):
+class TipoPersonaType(ScalarMap):
+    """
+    
+    :param persona_fisica:
+    :param persona_moral:
+    :param fideicomiso:
+    """
+    
     def __init__(
             self,
             persona_fisica: PersonaFisicaType | dict = None,
             persona_moral: PersonaMoralType | dict = None,
             fideicomiso: FideicomisoType | dict = None,
     ): 
-        """
-        
-        :param persona_fisica:
-        :param persona_moral:
-        :param fideicomiso:
-        """
-        
         super().__init__({
             'PersonaFisica': persona_fisica,
             'PersonaMoral': persona_moral,
@@ -598,20 +599,20 @@ class TipoPersonaType(XElement):
         })
         
 
-class PersonaAvisoType(XElement):
+class PersonaAvisoType(ScalarMap):
+    """
+    
+    :param tipo_persona:
+    :param tipo_domicilio:
+    :param telefono:
+    """
+    
     def __init__(
             self,
             tipo_persona: TipoPersonaType | dict,
             tipo_domicilio: TipoDomicilioType | dict = None,
             telefono: TelefonoType | dict = None,
     ): 
-        """
-        
-        :param tipo_persona:
-        :param tipo_domicilio:
-        :param telefono:
-        """
-        
         super().__init__({
             'TipoPersona': tipo_persona,
             'TipoDomicilio': tipo_domicilio,
@@ -619,43 +620,54 @@ class PersonaAvisoType(XElement):
         })
         
 
-class AlertaType(XElement):
+class AlertaType(ScalarMap):
+    """
+    
+    :param tipo_alerta:
+    :param descripcion_alerta:
+    """
+    
     def __init__(
             self,
             tipo_alerta: str,
             descripcion_alerta: str = None,
     ): 
-        """
-        
-        :param tipo_alerta:
-        :param descripcion_alerta:
-        """
-        
         super().__init__({
             'TipoAlerta': tipo_alerta,
             'DescripcionAlerta': descripcion_alerta,
         })
         
 
-class ModificatorioType(XElement):
+class ModificatorioType(ScalarMap):
+    """
+    
+    :param folio_modificacion:
+    :param descripcion_modificacion:
+    """
+    
     def __init__(
             self,
             folio_modificacion: str,
             descripcion_modificacion: str,
     ): 
-        """
-        
-        :param folio_modificacion:
-        :param descripcion_modificacion:
-        """
-        
         super().__init__({
             'FolioModificacion': folio_modificacion,
             'DescripcionModificacion': descripcion_modificacion,
         })
         
 
-class AvisoType(XElement):
+class AvisoType(ScalarMap):
+    """
+    
+    :param referencia_aviso:
+    :param prioridad:
+    :param alerta:
+    :param persona_aviso:
+    :param detalle_operaciones:
+    :param modificatorio:
+    :param dueno_beneficiario:
+    """
+    
     def __init__(
             self,
             referencia_aviso: str,
@@ -666,17 +678,6 @@ class AvisoType(XElement):
             modificatorio: ModificatorioType | dict = None,
             dueno_beneficiario: DuenoBeneficiarioType | dict | Sequence[DuenoBeneficiarioType | dict] = None,
     ): 
-        """
-        
-        :param referencia_aviso:
-        :param prioridad:
-        :param alerta:
-        :param persona_aviso:
-        :param detalle_operaciones:
-        :param modificatorio:
-        :param dueno_beneficiario:
-        """
-        
         super().__init__({
             'ReferenciaAviso': referencia_aviso,
             'Prioridad': prioridad,
@@ -688,7 +689,15 @@ class AvisoType(XElement):
         })
         
 
-class SujetoObligadoType(XElement):
+class SujetoObligadoType(ScalarMap):
+    """
+    
+    :param clave_sujeto_obligado:
+    :param clave_actividad:
+    :param clave_entidad_colegiada:
+    :param exento:
+    """
+    
     def __init__(
             self,
             clave_sujeto_obligado: str,
@@ -696,14 +705,6 @@ class SujetoObligadoType(XElement):
             clave_entidad_colegiada: str = None,
             exento: str = None,
     ): 
-        """
-        
-        :param clave_sujeto_obligado:
-        :param clave_actividad:
-        :param clave_entidad_colegiada:
-        :param exento:
-        """
-        
         super().__init__({
             'ClaveSujetoObligado': clave_sujeto_obligado,
             'ClaveActividad': clave_actividad,
@@ -712,20 +713,20 @@ class SujetoObligadoType(XElement):
         })
         
 
-class InformeType(XElement):
+class InformeType(ScalarMap):
+    """
+    
+    :param mes_reportado:
+    :param sujeto_obligado:
+    :param aviso:
+    """
+    
     def __init__(
             self,
             mes_reportado: str,
             sujeto_obligado: SujetoObligadoType | dict,
             aviso: AvisoType | dict | Sequence[AvisoType | dict] = None,
     ): 
-        """
-        
-        :param mes_reportado:
-        :param sujeto_obligado:
-        :param aviso:
-        """
-        
         super().__init__({
             'MesReportado': mes_reportado,
             'SujetoObligado': sujeto_obligado,
@@ -733,21 +734,21 @@ class InformeType(XElement):
         })
         
 
-class ArchivoType(XElement):
+class ArchivoType(ScalarMap):
+    """
+    
+    :param informe:
+    """
+    
     def __init__(
             self,
             informe: InformeType | dict | Sequence[InformeType | dict],
     ): 
-        """
-        
-        :param informe:
-        """
-        
         super().__init__({
             'Informe': informe,
         })
         
 
-class Archivo(ArchivoType):
+class Archivo(ArchivoType, XElement):
     tag = '{http://www.uif.shcp.gob.mx/recepcion/mpc}archivo'
 
