@@ -1,23 +1,24 @@
+"""tcv http://www.uif.shcp.gob.mx/recepcion/tcv"""
 from decimal import Decimal
 from datetime import datetime, date, time
 from collections.abc import Sequence
-from ...cfdi import CFDI, XElement
+from ... import CFDI, XElement, ScalarMap
 
 
-class FideicomisoDestinatarioType(XElement):
+class FideicomisoDestinatarioType(ScalarMap):
+    """
+    
+    :param denominacion_razon:
+    :param rfc:
+    :param identificador_fideicomiso:
+    """
+    
     def __init__(
             self,
             denominacion_razon: str,
             rfc: str = None,
             identificador_fideicomiso: str = None,
     ): 
-        """
-        
-        :param denominacion_razon:
-        :param rfc:
-        :param identificador_fideicomiso:
-        """
-        
         super().__init__({
             'DenominacionRazon': denominacion_razon,
             'Rfc': rfc,
@@ -25,20 +26,20 @@ class FideicomisoDestinatarioType(XElement):
         })
         
 
-class PersonaMoralDestinatarioType(XElement):
+class PersonaMoralDestinatarioType(ScalarMap):
+    """
+    
+    :param denominacion_razon:
+    :param fecha_constitucion:
+    :param rfc:
+    """
+    
     def __init__(
             self,
             denominacion_razon: str,
             fecha_constitucion: date = None,
             rfc: str = None,
     ): 
-        """
-        
-        :param denominacion_razon:
-        :param fecha_constitucion:
-        :param rfc:
-        """
-        
         super().__init__({
             'DenominacionRazon': denominacion_razon,
             'FechaConstitucion': fecha_constitucion,
@@ -46,7 +47,17 @@ class PersonaMoralDestinatarioType(XElement):
         })
         
 
-class PersonaFisicaDestinatarioType(XElement):
+class PersonaFisicaDestinatarioType(ScalarMap):
+    """
+    
+    :param nombre:
+    :param apellido_paterno:
+    :param apellido_materno:
+    :param fecha_nacimiento:
+    :param rfc:
+    :param curp:
+    """
+    
     def __init__(
             self,
             nombre: str,
@@ -56,16 +67,6 @@ class PersonaFisicaDestinatarioType(XElement):
             rfc: str = None,
             curp: str = None,
     ): 
-        """
-        
-        :param nombre:
-        :param apellido_paterno:
-        :param apellido_materno:
-        :param fecha_nacimiento:
-        :param rfc:
-        :param curp:
-        """
-        
         super().__init__({
             'Nombre': nombre,
             'ApellidoPaterno': apellido_paterno,
@@ -76,20 +77,20 @@ class PersonaFisicaDestinatarioType(XElement):
         })
         
 
-class TipoPersonaDestinatarioType(XElement):
+class TipoPersonaDestinatarioType(ScalarMap):
+    """
+    
+    :param persona_fisica:
+    :param persona_moral:
+    :param fideicomiso:
+    """
+    
     def __init__(
             self,
             persona_fisica: PersonaFisicaDestinatarioType | dict = None,
             persona_moral: PersonaMoralDestinatarioType | dict = None,
             fideicomiso: FideicomisoDestinatarioType | dict = None,
     ): 
-        """
-        
-        :param persona_fisica:
-        :param persona_moral:
-        :param fideicomiso:
-        """
-        
         super().__init__({
             'PersonaFisica': persona_fisica,
             'PersonaMoral': persona_moral,
@@ -97,25 +98,33 @@ class TipoPersonaDestinatarioType(XElement):
         })
         
 
-class DestinatarioType(XElement):
+class DestinatarioType(ScalarMap):
+    """
+    
+    :param destinatario_persona_aviso:
+    :param tipo_persona:
+    """
+    
     def __init__(
             self,
             destinatario_persona_aviso: str,
             tipo_persona: TipoPersonaDestinatarioType | dict = None,
     ): 
-        """
-        
-        :param destinatario_persona_aviso:
-        :param tipo_persona:
-        """
-        
         super().__init__({
             'DestinatarioPersonaAviso': destinatario_persona_aviso,
             'TipoPersona': tipo_persona,
         })
         
 
-class ExtranjeroEntregaType(XElement):
+class ExtranjeroEntregaType(ScalarMap):
+    """
+    
+    :param pais:
+    :param estado_provincia:
+    :param ciudad_poblacion:
+    :param codigo_postal:
+    """
+    
     def __init__(
             self,
             pais: str,
@@ -123,14 +132,6 @@ class ExtranjeroEntregaType(XElement):
             ciudad_poblacion: str,
             codigo_postal: str,
     ): 
-        """
-        
-        :param pais:
-        :param estado_provincia:
-        :param ciudad_poblacion:
-        :param codigo_postal:
-        """
-        
         super().__init__({
             'Pais': pais,
             'EstadoProvincia': estado_provincia,
@@ -139,58 +140,67 @@ class ExtranjeroEntregaType(XElement):
         })
         
 
-class NacionalEntregaType(XElement):
+class NacionalEntregaType(ScalarMap):
+    """
+    
+    :param codigo_postal:
+    """
+    
     def __init__(
             self,
             codigo_postal: str,
     ): 
-        """
-        
-        :param codigo_postal:
-        """
-        
         super().__init__({
             'CodigoPostal': codigo_postal,
         })
         
 
-class TipoEntregaType(XElement):
+class TipoEntregaType(ScalarMap):
+    """
+    
+    :param nacional:
+    :param extranjero:
+    """
+    
     def __init__(
             self,
             nacional: NacionalEntregaType | dict = None,
             extranjero: ExtranjeroEntregaType | dict = None,
     ): 
-        """
-        
-        :param nacional:
-        :param extranjero:
-        """
-        
         super().__init__({
             'Nacional': nacional,
             'Extranjero': extranjero,
         })
         
 
-class EntregaType(XElement):
+class EntregaType(ScalarMap):
+    """
+    
+    :param fecha_entrega:
+    :param tipo_entrega:
+    """
+    
     def __init__(
             self,
             fecha_entrega: date,
             tipo_entrega: TipoEntregaType | dict,
     ): 
-        """
-        
-        :param fecha_entrega:
-        :param tipo_entrega:
-        """
-        
         super().__init__({
             'FechaEntrega': fecha_entrega,
             'TipoEntrega': tipo_entrega,
         })
         
 
-class DatosNoSucursalType(XElement):
+class DatosNoSucursalType(ScalarMap):
+    """
+    
+    :param colonia:
+    :param calle:
+    :param numero_exterior:
+    :param codigo_postal:
+    :param numero_interior:
+    """
+    
     def __init__(
             self,
             colonia: str,
@@ -199,15 +209,6 @@ class DatosNoSucursalType(XElement):
             codigo_postal: str,
             numero_interior: str = None,
     ): 
-        """
-        
-        :param colonia:
-        :param calle:
-        :param numero_exterior:
-        :param codigo_postal:
-        :param numero_interior:
-        """
-        
         super().__init__({
             'Colonia': colonia,
             'Calle': calle,
@@ -217,53 +218,53 @@ class DatosNoSucursalType(XElement):
         })
         
 
-class DatosSucursalType(XElement):
+class DatosSucursalType(ScalarMap):
+    """
+    
+    :param codigo_postal:
+    """
+    
     def __init__(
             self,
             codigo_postal: str,
     ): 
-        """
-        
-        :param codigo_postal:
-        """
-        
         super().__init__({
             'CodigoPostal': codigo_postal,
         })
         
 
-class TipoCustodiaType(XElement):
+class TipoCustodiaType(ScalarMap):
+    """
+    
+    :param datos_sucursal:
+    :param datos_no_sucursal:
+    """
+    
     def __init__(
             self,
             datos_sucursal: DatosSucursalType | dict = None,
             datos_no_sucursal: DatosNoSucursalType | dict = None,
     ): 
-        """
-        
-        :param datos_sucursal:
-        :param datos_no_sucursal:
-        """
-        
         super().__init__({
             'DatosSucursal': datos_sucursal,
             'DatosNoSucursal': datos_no_sucursal,
         })
         
 
-class CustodiaType(XElement):
+class CustodiaType(ScalarMap):
+    """
+    
+    :param fecha_inicio:
+    :param fecha_fin:
+    :param tipo_custodia:
+    """
+    
     def __init__(
             self,
             fecha_inicio: date,
             fecha_fin: date,
             tipo_custodia: TipoCustodiaType | dict,
     ): 
-        """
-        
-        :param fecha_inicio:
-        :param fecha_fin:
-        :param tipo_custodia:
-        """
-        
         super().__init__({
             'FechaInicio': fecha_inicio,
             'FechaFin': fecha_fin,
@@ -271,20 +272,20 @@ class CustodiaType(XElement):
         })
         
 
-class RecepcionType(XElement):
+class RecepcionType(ScalarMap):
+    """
+    
+    :param tipo_servicio:
+    :param fecha_recepcion:
+    :param codigo_postal:
+    """
+    
     def __init__(
             self,
             tipo_servicio: str,
             fecha_recepcion: date,
             codigo_postal: str,
     ): 
-        """
-        
-        :param tipo_servicio:
-        :param fecha_recepcion:
-        :param codigo_postal:
-        """
-        
         super().__init__({
             'TipoServicio': tipo_servicio,
             'FechaRecepcion': fecha_recepcion,
@@ -292,20 +293,20 @@ class RecepcionType(XElement):
         })
         
 
-class DatosValoresType(XElement):
+class DatosValoresType(ScalarMap):
+    """
+    
+    :param tipo_valor:
+    :param valor_objeto:
+    :param descripcion:
+    """
+    
     def __init__(
             self,
             tipo_valor: str,
             valor_objeto: str,
             descripcion: str,
     ): 
-        """
-        
-        :param tipo_valor:
-        :param valor_objeto:
-        :param descripcion:
-        """
-        
         super().__init__({
             'TipoValor': tipo_valor,
             'ValorObjeto': valor_objeto,
@@ -313,20 +314,20 @@ class DatosValoresType(XElement):
         })
         
 
-class DatosEfectivoInstrumentosType(XElement):
+class DatosEfectivoInstrumentosType(ScalarMap):
+    """
+    
+    :param instrumento_monetario:
+    :param moneda:
+    :param monto_operacion:
+    """
+    
     def __init__(
             self,
             instrumento_monetario: str,
             moneda: str,
             monto_operacion: str,
     ): 
-        """
-        
-        :param instrumento_monetario:
-        :param moneda:
-        :param monto_operacion:
-        """
-        
         super().__init__({
             'InstrumentoMonetario': instrumento_monetario,
             'Moneda': moneda,
@@ -334,25 +335,36 @@ class DatosEfectivoInstrumentosType(XElement):
         })
         
 
-class TipoBienType(XElement):
+class TipoBienType(ScalarMap):
+    """
+    
+    :param datos_efectivo_instrumentos:
+    :param datos_valores:
+    """
+    
     def __init__(
             self,
             datos_efectivo_instrumentos: DatosEfectivoInstrumentosType | dict = None,
             datos_valores: DatosValoresType | dict = None,
     ): 
-        """
-        
-        :param datos_efectivo_instrumentos:
-        :param datos_valores:
-        """
-        
         super().__init__({
             'DatosEfectivoInstrumentos': datos_efectivo_instrumentos,
             'DatosValores': datos_valores,
         })
         
 
-class DatosOperacionType(XElement):
+class DatosOperacionType(ScalarMap):
+    """
+    
+    :param fecha_operacion:
+    :param tipo_operacion:
+    :param tipo_bien:
+    :param recepcion:
+    :param custodia:
+    :param entrega:
+    :param destinatario:
+    """
+    
     def __init__(
             self,
             fecha_operacion: date,
@@ -363,17 +375,6 @@ class DatosOperacionType(XElement):
             entrega: EntregaType | dict = None,
             destinatario: DestinatarioType | dict = None,
     ): 
-        """
-        
-        :param fecha_operacion:
-        :param tipo_operacion:
-        :param tipo_bien:
-        :param recepcion:
-        :param custodia:
-        :param entrega:
-        :param destinatario:
-        """
-        
         super().__init__({
             'FechaOperacion': fecha_operacion,
             'TipoOperacion': tipo_operacion,
@@ -385,35 +386,35 @@ class DatosOperacionType(XElement):
         })
         
 
-class DetalleOperacionesType(XElement):
+class DetalleOperacionesType(ScalarMap):
+    """
+    
+    :param datos_operacion:
+    """
+    
     def __init__(
             self,
             datos_operacion: DatosOperacionType | dict | Sequence[DatosOperacionType | dict],
     ): 
-        """
-        
-        :param datos_operacion:
-        """
-        
         super().__init__({
             'DatosOperacion': datos_operacion,
         })
         
 
-class FideicomisoSimpleType(XElement):
+class FideicomisoSimpleType(ScalarMap):
+    """
+    
+    :param denominacion_razon:
+    :param rfc:
+    :param identificador_fideicomiso:
+    """
+    
     def __init__(
             self,
             denominacion_razon: str,
             rfc: str = None,
             identificador_fideicomiso: str = None,
     ): 
-        """
-        
-        :param denominacion_razon:
-        :param rfc:
-        :param identificador_fideicomiso:
-        """
-        
         super().__init__({
             'DenominacionRazon': denominacion_razon,
             'Rfc': rfc,
@@ -421,7 +422,15 @@ class FideicomisoSimpleType(XElement):
         })
         
 
-class PersonaMoralSimpleType(XElement):
+class PersonaMoralSimpleType(ScalarMap):
+    """
+    
+    :param denominacion_razon:
+    :param fecha_constitucion:
+    :param rfc:
+    :param pais_nacionalidad:
+    """
+    
     def __init__(
             self,
             denominacion_razon: str,
@@ -429,14 +438,6 @@ class PersonaMoralSimpleType(XElement):
             rfc: str = None,
             pais_nacionalidad: str = None,
     ): 
-        """
-        
-        :param denominacion_razon:
-        :param fecha_constitucion:
-        :param rfc:
-        :param pais_nacionalidad:
-        """
-        
         super().__init__({
             'DenominacionRazon': denominacion_razon,
             'FechaConstitucion': fecha_constitucion,
@@ -445,7 +446,18 @@ class PersonaMoralSimpleType(XElement):
         })
         
 
-class PersonaFisicaSimpleType(XElement):
+class PersonaFisicaSimpleType(ScalarMap):
+    """
+    
+    :param nombre:
+    :param apellido_paterno:
+    :param apellido_materno:
+    :param fecha_nacimiento:
+    :param rfc:
+    :param curp:
+    :param pais_nacionalidad:
+    """
+    
     def __init__(
             self,
             nombre: str,
@@ -456,17 +468,6 @@ class PersonaFisicaSimpleType(XElement):
             curp: str = None,
             pais_nacionalidad: str = None,
     ): 
-        """
-        
-        :param nombre:
-        :param apellido_paterno:
-        :param apellido_materno:
-        :param fecha_nacimiento:
-        :param rfc:
-        :param curp:
-        :param pais_nacionalidad:
-        """
-        
         super().__init__({
             'Nombre': nombre,
             'ApellidoPaterno': apellido_paterno,
@@ -478,20 +479,20 @@ class PersonaFisicaSimpleType(XElement):
         })
         
 
-class TipoPersonaSimpleType(XElement):
+class TipoPersonaSimpleType(ScalarMap):
+    """
+    
+    :param persona_fisica:
+    :param persona_moral:
+    :param fideicomiso:
+    """
+    
     def __init__(
             self,
             persona_fisica: PersonaFisicaSimpleType | dict = None,
             persona_moral: PersonaMoralSimpleType | dict = None,
             fideicomiso: FideicomisoSimpleType | dict = None,
     ): 
-        """
-        
-        :param persona_fisica:
-        :param persona_moral:
-        :param fideicomiso:
-        """
-        
         super().__init__({
             'PersonaFisica': persona_fisica,
             'PersonaMoral': persona_moral,
@@ -499,35 +500,35 @@ class TipoPersonaSimpleType(XElement):
         })
         
 
-class DuenoBeneficiarioType(XElement):
+class DuenoBeneficiarioType(ScalarMap):
+    """
+    
+    :param tipo_persona:
+    """
+    
     def __init__(
             self,
             tipo_persona: TipoPersonaSimpleType | dict,
     ): 
-        """
-        
-        :param tipo_persona:
-        """
-        
         super().__init__({
             'TipoPersona': tipo_persona,
         })
         
 
-class TelefonoType(XElement):
+class TelefonoType(ScalarMap):
+    """
+    
+    :param clave_pais:
+    :param numero_telefono:
+    :param correo_electronico:
+    """
+    
     def __init__(
             self,
             clave_pais: str = None,
             numero_telefono: str = None,
             correo_electronico: str = None,
     ): 
-        """
-        
-        :param clave_pais:
-        :param numero_telefono:
-        :param correo_electronico:
-        """
-        
         super().__init__({
             'ClavePais': clave_pais,
             'NumeroTelefono': numero_telefono,
@@ -535,7 +536,19 @@ class TelefonoType(XElement):
         })
         
 
-class ExtranjeroType(XElement):
+class ExtranjeroType(ScalarMap):
+    """
+    
+    :param pais:
+    :param estado_provincia:
+    :param ciudad_poblacion:
+    :param colonia:
+    :param calle:
+    :param numero_exterior:
+    :param codigo_postal:
+    :param numero_interior:
+    """
+    
     def __init__(
             self,
             pais: str,
@@ -547,18 +560,6 @@ class ExtranjeroType(XElement):
             codigo_postal: str,
             numero_interior: str = None,
     ): 
-        """
-        
-        :param pais:
-        :param estado_provincia:
-        :param ciudad_poblacion:
-        :param colonia:
-        :param calle:
-        :param numero_exterior:
-        :param codigo_postal:
-        :param numero_interior:
-        """
-        
         super().__init__({
             'Pais': pais,
             'EstadoProvincia': estado_provincia,
@@ -571,7 +572,16 @@ class ExtranjeroType(XElement):
         })
         
 
-class NacionalType(XElement):
+class NacionalType(ScalarMap):
+    """
+    
+    :param colonia:
+    :param calle:
+    :param numero_exterior:
+    :param codigo_postal:
+    :param numero_interior:
+    """
+    
     def __init__(
             self,
             colonia: str,
@@ -580,15 +590,6 @@ class NacionalType(XElement):
             codigo_postal: str,
             numero_interior: str = None,
     ): 
-        """
-        
-        :param colonia:
-        :param calle:
-        :param numero_exterior:
-        :param codigo_postal:
-        :param numero_interior:
-        """
-        
         super().__init__({
             'Colonia': colonia,
             'Calle': calle,
@@ -598,25 +599,35 @@ class NacionalType(XElement):
         })
         
 
-class TipoDomicilioType(XElement):
+class TipoDomicilioType(ScalarMap):
+    """
+    
+    :param nacional:
+    :param extranjero:
+    """
+    
     def __init__(
             self,
             nacional: NacionalType | dict = None,
             extranjero: ExtranjeroType | dict = None,
     ): 
-        """
-        
-        :param nacional:
-        :param extranjero:
-        """
-        
         super().__init__({
             'Nacional': nacional,
             'Extranjero': extranjero,
         })
         
 
-class RepresentanteApoderadoType(XElement):
+class RepresentanteApoderadoType(ScalarMap):
+    """
+    
+    :param nombre:
+    :param apellido_paterno:
+    :param apellido_materno:
+    :param fecha_nacimiento:
+    :param rfc:
+    :param curp:
+    """
+    
     def __init__(
             self,
             nombre: str,
@@ -626,16 +637,6 @@ class RepresentanteApoderadoType(XElement):
             rfc: str = None,
             curp: str = None,
     ): 
-        """
-        
-        :param nombre:
-        :param apellido_paterno:
-        :param apellido_materno:
-        :param fecha_nacimiento:
-        :param rfc:
-        :param curp:
-        """
-        
         super().__init__({
             'Nombre': nombre,
             'ApellidoPaterno': apellido_paterno,
@@ -646,7 +647,15 @@ class RepresentanteApoderadoType(XElement):
         })
         
 
-class FideicomisoType(XElement):
+class FideicomisoType(ScalarMap):
+    """
+    
+    :param denominacion_razon:
+    :param apoderado_delegado:
+    :param rfc:
+    :param identificador_fideicomiso:
+    """
+    
     def __init__(
             self,
             denominacion_razon: str,
@@ -654,14 +663,6 @@ class FideicomisoType(XElement):
             rfc: str = None,
             identificador_fideicomiso: str = None,
     ): 
-        """
-        
-        :param denominacion_razon:
-        :param apoderado_delegado:
-        :param rfc:
-        :param identificador_fideicomiso:
-        """
-        
         super().__init__({
             'DenominacionRazon': denominacion_razon,
             'ApoderadoDelegado': apoderado_delegado,
@@ -670,7 +671,17 @@ class FideicomisoType(XElement):
         })
         
 
-class PersonaMoralType(XElement):
+class PersonaMoralType(ScalarMap):
+    """
+    
+    :param denominacion_razon:
+    :param pais_nacionalidad:
+    :param giro_mercantil:
+    :param representante_apoderado:
+    :param fecha_constitucion:
+    :param rfc:
+    """
+    
     def __init__(
             self,
             denominacion_razon: str,
@@ -680,16 +691,6 @@ class PersonaMoralType(XElement):
             fecha_constitucion: date = None,
             rfc: str = None,
     ): 
-        """
-        
-        :param denominacion_razon:
-        :param pais_nacionalidad:
-        :param giro_mercantil:
-        :param representante_apoderado:
-        :param fecha_constitucion:
-        :param rfc:
-        """
-        
         super().__init__({
             'DenominacionRazon': denominacion_razon,
             'PaisNacionalidad': pais_nacionalidad,
@@ -700,7 +701,19 @@ class PersonaMoralType(XElement):
         })
         
 
-class PersonaFisicaType(XElement):
+class PersonaFisicaType(ScalarMap):
+    """
+    
+    :param nombre:
+    :param apellido_paterno:
+    :param apellido_materno:
+    :param pais_nacionalidad:
+    :param actividad_economica:
+    :param fecha_nacimiento:
+    :param rfc:
+    :param curp:
+    """
+    
     def __init__(
             self,
             nombre: str,
@@ -712,18 +725,6 @@ class PersonaFisicaType(XElement):
             rfc: str = None,
             curp: str = None,
     ): 
-        """
-        
-        :param nombre:
-        :param apellido_paterno:
-        :param apellido_materno:
-        :param pais_nacionalidad:
-        :param actividad_economica:
-        :param fecha_nacimiento:
-        :param rfc:
-        :param curp:
-        """
-        
         super().__init__({
             'Nombre': nombre,
             'ApellidoPaterno': apellido_paterno,
@@ -736,20 +737,20 @@ class PersonaFisicaType(XElement):
         })
         
 
-class TipoPersonaType(XElement):
+class TipoPersonaType(ScalarMap):
+    """
+    
+    :param persona_fisica:
+    :param persona_moral:
+    :param fideicomiso:
+    """
+    
     def __init__(
             self,
             persona_fisica: PersonaFisicaType | dict = None,
             persona_moral: PersonaMoralType | dict = None,
             fideicomiso: FideicomisoType | dict = None,
     ): 
-        """
-        
-        :param persona_fisica:
-        :param persona_moral:
-        :param fideicomiso:
-        """
-        
         super().__init__({
             'PersonaFisica': persona_fisica,
             'PersonaMoral': persona_moral,
@@ -757,20 +758,20 @@ class TipoPersonaType(XElement):
         })
         
 
-class PersonaAvisoType(XElement):
+class PersonaAvisoType(ScalarMap):
+    """
+    
+    :param tipo_persona:
+    :param tipo_domicilio:
+    :param telefono:
+    """
+    
     def __init__(
             self,
             tipo_persona: TipoPersonaType | dict,
             tipo_domicilio: TipoDomicilioType | dict = None,
             telefono: TelefonoType | dict = None,
     ): 
-        """
-        
-        :param tipo_persona:
-        :param tipo_domicilio:
-        :param telefono:
-        """
-        
         super().__init__({
             'TipoPersona': tipo_persona,
             'TipoDomicilio': tipo_domicilio,
@@ -778,43 +779,54 @@ class PersonaAvisoType(XElement):
         })
         
 
-class AlertaType(XElement):
+class AlertaType(ScalarMap):
+    """
+    
+    :param tipo_alerta:
+    :param descripcion_alerta:
+    """
+    
     def __init__(
             self,
             tipo_alerta: str,
             descripcion_alerta: str = None,
     ): 
-        """
-        
-        :param tipo_alerta:
-        :param descripcion_alerta:
-        """
-        
         super().__init__({
             'TipoAlerta': tipo_alerta,
             'DescripcionAlerta': descripcion_alerta,
         })
         
 
-class ModificatorioType(XElement):
+class ModificatorioType(ScalarMap):
+    """
+    
+    :param folio_modificacion:
+    :param descripcion_modificacion:
+    """
+    
     def __init__(
             self,
             folio_modificacion: str,
             descripcion_modificacion: str,
     ): 
-        """
-        
-        :param folio_modificacion:
-        :param descripcion_modificacion:
-        """
-        
         super().__init__({
             'FolioModificacion': folio_modificacion,
             'DescripcionModificacion': descripcion_modificacion,
         })
         
 
-class AvisoType(XElement):
+class AvisoType(ScalarMap):
+    """
+    
+    :param referencia_aviso:
+    :param prioridad:
+    :param alerta:
+    :param persona_aviso:
+    :param detalle_operaciones:
+    :param modificatorio:
+    :param dueno_beneficiario:
+    """
+    
     def __init__(
             self,
             referencia_aviso: str,
@@ -825,17 +837,6 @@ class AvisoType(XElement):
             modificatorio: ModificatorioType | dict = None,
             dueno_beneficiario: DuenoBeneficiarioType | dict | Sequence[DuenoBeneficiarioType | dict] = None,
     ): 
-        """
-        
-        :param referencia_aviso:
-        :param prioridad:
-        :param alerta:
-        :param persona_aviso:
-        :param detalle_operaciones:
-        :param modificatorio:
-        :param dueno_beneficiario:
-        """
-        
         super().__init__({
             'ReferenciaAviso': referencia_aviso,
             'Prioridad': prioridad,
@@ -847,7 +848,15 @@ class AvisoType(XElement):
         })
         
 
-class SujetoObligadoType(XElement):
+class SujetoObligadoType(ScalarMap):
+    """
+    
+    :param clave_sujeto_obligado:
+    :param clave_actividad:
+    :param clave_entidad_colegiada:
+    :param exento:
+    """
+    
     def __init__(
             self,
             clave_sujeto_obligado: str,
@@ -855,14 +864,6 @@ class SujetoObligadoType(XElement):
             clave_entidad_colegiada: str = None,
             exento: str = None,
     ): 
-        """
-        
-        :param clave_sujeto_obligado:
-        :param clave_actividad:
-        :param clave_entidad_colegiada:
-        :param exento:
-        """
-        
         super().__init__({
             'ClaveSujetoObligado': clave_sujeto_obligado,
             'ClaveActividad': clave_actividad,
@@ -871,20 +872,20 @@ class SujetoObligadoType(XElement):
         })
         
 
-class InformeType(XElement):
+class InformeType(ScalarMap):
+    """
+    
+    :param mes_reportado:
+    :param sujeto_obligado:
+    :param aviso:
+    """
+    
     def __init__(
             self,
             mes_reportado: str,
             sujeto_obligado: SujetoObligadoType | dict,
             aviso: AvisoType | dict | Sequence[AvisoType | dict] = None,
     ): 
-        """
-        
-        :param mes_reportado:
-        :param sujeto_obligado:
-        :param aviso:
-        """
-        
         super().__init__({
             'MesReportado': mes_reportado,
             'SujetoObligado': sujeto_obligado,
@@ -892,21 +893,21 @@ class InformeType(XElement):
         })
         
 
-class ArchivoType(XElement):
+class ArchivoType(ScalarMap):
+    """
+    
+    :param informe:
+    """
+    
     def __init__(
             self,
             informe: InformeType | dict | Sequence[InformeType | dict],
     ): 
-        """
-        
-        :param informe:
-        """
-        
         super().__init__({
             'Informe': informe,
         })
         
 
-class Archivo(ArchivoType):
+class Archivo(ArchivoType, XElement):
     tag = '{http://www.uif.shcp.gob.mx/recepcion/tcv}archivo'
 
