@@ -1,5 +1,5 @@
 import logging
-
+from enum import Enum
 
 logger = logging.getLogger(__name__)
 
@@ -29,9 +29,7 @@ class Code:
     def __eq__(self, other):
         if isinstance(other, Code):
             return self.code == other.code
-        if isinstance(other, str) or isinstance(other, int):
-            return self.code == other
-        return NotImplemented
+        return self.code == other
 
     def __hash__(self):
         return self.code.__hash__()
