@@ -23,9 +23,8 @@ from .. import CFDI, __version__, ResponseError, Signer, Certificate
 from . import PAC, Environment, TaxpayerStatus
 from ..create.w3.signature import signature_c14n_sha1, _digest, _tobytes
 from ..transform import MEXICO_TZ, get_timezone, verify_certificate
-from ..utils import iterate
+from ..utils import iterate, StrEnum, parser
 
-parser = etree.XMLParser(remove_blank_text=True, huge_tree=True)
 logger = logging.getLogger(__name__)
 current_dir = os.path.dirname(__file__)
 
@@ -42,12 +41,12 @@ class EstadoSolicitud(IntEnum):
     Vencida = 6
 
 
-class TipoDescargaMasivaTerceros(Enum):
+class TipoDescargaMasivaTerceros(StrEnum):
     CFDI = 'CFDI'
     Metadata = 'Metadata'
 
 
-class TipoDeComprobante(Enum):
+class TipoDeComprobante(StrEnum):
     Ingreso = 'I'
     Egreso = 'E'
     Traslado = 'T'
@@ -55,7 +54,7 @@ class TipoDeComprobante(Enum):
     Pago = 'P'
 
 
-class EstadoComprobante(Enum):
+class EstadoComprobante(StrEnum):
     Cancelado = '0'
     Vigente = '1'
 
@@ -556,14 +555,14 @@ class SAT(PAC):
             'FechaFinal': fecha_final,
             'FechaInicial': fecha_inicial,
             'RfcEmisor': rfc_emisor,
-            'RfcReceptores': [('RfcReceptor', r) for r in iterate(rfc_receptor)],
+            'RfcReceptores': [('RfcReceptor', r) for r in iterate(rfc_receptor)] if rfc_receptor else None,
             'RfcSolicitante': self.signer.rfc,
             'TipoSolicitud': tipo_solicitud,
             'TipoComprobante': tipo_comprobante,
             'EstadoComprobante': estado_comprobante,
             'RfcACuentaTerceros': rfc_a_cuenta_terceros,
             'Complemento': complemento,
-            'UUID': uuid,
+            'Folio': uuid,
         }
 
         return self._execute_req(
@@ -704,14 +703,14 @@ class SAT(PAC):
             'FechaFinal': fecha_final,
             'FechaInicial': fecha_inicial,
             'RfcEmisor': rfc_emisor,
-            'RfcReceptores': [('RfcReceptor', r) for r in iterate(rfc_receptor)],
+            'RfcReceptores': [('RfcReceptor', r) for r in iterate(rfc_receptor)] if rfc_receptor else None,
             'RfcSolicitante': self.signer.rfc,
             'TipoSolicitud': tipo_solicitud,
             'TipoComprobante': tipo_comprobante,
             'EstadoComprobante': estado_comprobante,
             'RfcACuentaTerceros': rfc_a_cuenta_terceros,
             'Complemento': complemento,
-            'UUID': uuid,
+            'Folio': uuid,
         }
 
         return self._execute_req(
