@@ -1,6 +1,10 @@
 import enum
 from collections.abc import Sequence, Mapping
 
+from lxml import etree
+
+parser = etree.XMLParser(no_network=True, remove_comments=True, remove_blank_text=True, huge_tree=True, collect_ids=False, remove_pis=True)
+
 
 class ScalarMap(dict):
     pass
@@ -18,7 +22,9 @@ def iterate(item):
     return [item]
 
 
-class StrEnum(str, enum.Enum):
+class StrEnum(str, enum.Enum):  # Compatible with Python 3.10
     def __str__(self):
-        return str(self.value)
+        return self.value
 
+    def __format__(self, format_spec):
+        return self.value.__format__(format_spec)
